buildings = {
    'Protoss': {
        'Nexus': {
            'obj_id': [81],
            'priority': 28,
            'type': ['building', 'supply'],
            'mineral_cost': 400,
            'gas_cost': 0,
            'supply': 15,
        },
        'Pylon': {
            'obj_id': [82],
            'priority': 1,
            'type': ['building', 'supply'],
            'mineral_cost': 100,
            'gas_cost': 0,
            'supply': 8,
        },
        'Assimilator': {
            'obj_id': [83],
            'priority': 3,
            'type': ['building'],
            'mineral_cost': 75,
            'gas_cost': 0,
            'supply': 0,
        },
        'Gateway': {
            'obj_id': [84],
            'priority': 24,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'WarpGate': {
            'obj_id': [155],
            'priority': 30,
            'type': ['building'],
            'mineral_cost': 0,
            'gas_cost': 0,
            'supply': 0,
        },
        'Forge': {
            'obj_id': [85],
            'priority': 18,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'CyberneticsCore': {
            'obj_id': [94],
            'priority': 16,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'PhotonCannon': {
            'obj_id': [88],
            'priority': 4,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'ShieldBattery': {
            'obj_id': [443],
            'priority': 5,
            'type': ['building'],
            'mineral_cost': 100,
            'gas_cost': 0,
            'supply': 0,
        },
        'RoboticsFacility': {
            'obj_id': [93],
            'priority': 22,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 100,
            'supply': 0,
        },
        'Stargate': {
            'obj_id': [89],
            'priority': 20,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 150,
            'supply': 0,
        },
        'TwilightCouncil': {
            'obj_id': [87],
            'priority': 12,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 100,
            'supply': 0,
        },
        'RoboticsBay': {
            'obj_id': [92],
            'priority': 6,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 150,
            'supply': 0,
        },
        'FleetBeacon': {
            'obj_id': [86],
            'priority': 14,
            'type': ['building'],
            'mineral_cost': 300,
            'gas_cost': 200,
            'supply': 0,
        },
        'TemplarArchives': {
            'obj_id': [90],
            'priority': 10,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 200,
            'supply': 0,
        },
        'DarkShrine': {
            'obj_id': [91],
            'priority': 8,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 150,
            'supply': 0,
        },
    },
    'Terran': {
        'CommandCenter': {
            'obj_id': [39],
            'priority': 32,
            'type': ['building', 'supply'],
            'mineral_cost': 400,
            'gas_cost': 0,
            'supply': 15,
        },
        'CommandCenterFlying': {
            'obj_id': [39],
            'priority': 32,
            'type': ['building', 'supply'],
            'mineral_cost': 400,
            'gas_cost': 0,
            'supply': 15,
        },
        'OrbitalCommand': {
            'obj_id': [154],
            'priority': 34,
            'type': ['building', 'supply'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'OrbitalCommandFlying': {
            'obj_id': [154],
            'priority': 34,
            'type': ['building', 'supply'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'PlanetaryFortress': {
            'obj_id': [152],
            'priority': 30,
            'type': ['building', 'supply'],
            'mineral_cost': 150,
            'gas_cost': 150,
            'supply': 0,
        },
        'SupplyDepot': {
            'obj_id': [40],
            'priority': 26,
            'type': ['building', 'supply'],
            'mineral_cost': 100,
            'gas_cost': 0,
            'supply': 8,
        },
        'SupplyDepotLowered': {
            'obj_id': [40],
            'priority': 26,
            'type': ['building', 'supply'],
            'mineral_cost': 0,
            'gas_cost': 0,
            'supply': 0,
        },
        'Refinery': {
            'obj_id': [41],
            'priority': 1,
            'type': ['building'],
            'mineral_cost': 75,
            'gas_cost': 0,
            'supply': 0,
        },
        'Barracks': {
            'obj_id': [42],
            'priority': 24,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'BarracksFlying': {
            'obj_id': [42],
            'priority': 24,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'EngineeringBay': {
            'obj_id': [43],
            'priority': 18,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'Bunker': {
            'obj_id': [45],
            'priority': 12,
            'type': ['building'],
            'mineral_cost': 100,
            'gas_cost': 0,
            'supply': 0,
        },
        'MissileTurret': {
            'obj_id': [44],
            'priority': 14,
            'type': ['building'],
            'mineral_cost': 100,
            'gas_cost': 0,
            'supply': 0,
        },
        'SensorTower': {
            'obj_id': [46],
            'priority': 10,
            'type': ['building'],
            'mineral_cost': 125,
            'gas_cost': 100,
            'supply': 0,
        },
        'GhostAcademy': {
            'obj_id': [47],
            'priority': 8,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 50,
            'supply': 0,
        },
        'Factory': {
            'obj_id': [48],
            'priority': 22,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 100,
            'supply': 0,
        },
        'FactoryFlying': {
            'obj_id': [48],
            'priority': 22,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 100,
            'supply': 0,
        },
        'Starport': {
            'obj_id': [49],
            'priority': 20,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 100,
            'supply': 0,
        },
        'StarportFlying': {
            'obj_id': [49],
            'priority': 20,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 100,
            'supply': 0,
        },
        'Armory': {
            'obj_id': [51],
            'priority': 16,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 100,
            'supply': 0,
        },
        'FusionCore': {
            'obj_id': [52],
            'priority': 7,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 150,
            'supply': 0,
        },
        'BarracksTechLab': {
            'obj_id': [59],
            'priority': 2,
            'type': ['building'],
            'mineral_cost': 50,
            'gas_cost': 25,
            'supply': 0,
        },
        'FactoryTechLab': {
            'obj_id': [61],
            'priority': 2,
            'type': ['building'],
            'mineral_cost': 50,
            'gas_cost': 25,
            'supply': 0,
        },
        'StarportTechLab': {
            'obj_id': [63],
            'priority': 2,
            'type': ['building'],
            'mineral_cost': 50,
            'gas_cost': 25,
            'supply': 0,
        },
        'BarracksReactor': {
            'obj_id': [25],
            'priority': 1,
            'type': ['building'],
            'mineral_cost': 50,
            'gas_cost': 50,
            'supply': 0,
        },
        'FactoryReactor': {
            'obj_id': [25],
            'priority': 1,
            'type': ['building'],
            'mineral_cost': 50,
            'gas_cost': 50,
            'supply': 0,
        },
        'StarportReactor': {
            'obj_id': [25],
            'priority': 1,
            'type': ['building'],
            'mineral_cost': 50,
            'gas_cost': 50,
            'supply': 0,
        },
    },
    'Zerg': {
        'Hatchery': {
            'obj_id': [108],
            'priority': 32,
            'type': ['building', 'supply'],
            'mineral_cost': 300,
            'gas_cost': 0,
            'supply': 6,
        },
        'Extractor': {
            'obj_id': [110],
            'priority': 1,
            'type': ['building'],
            'mineral_cost': 25,
            'gas_cost': 0,
            'supply': 0,
        },
        'SpawningPool': {
            'obj_id': [111],
            'priority': 20,
            'type': ['building'],
            'mineral_cost': 200,
            'gas_cost': 0,
            'supply': 0,
        },
        'SpineCrawler': {
            'obj_id': [161],
            'priority': 4,
            'type': ['building'],
            'mineral_cost': 100,
            'gas_cost': 0,
            'supply': 0,
        },
        'SporeCrawler': {
            'obj_id': [162],
            'priority': 4,
            'type': ['building'],
            'mineral_cost': 75,
            'gas_cost': 0,
            'supply': 0,
        },
        'EvolutionChamber': {
            'obj_id': [112],
            'priority': 26,
            'type': ['building'],
            'mineral_cost': 75,
            'gas_cost': 0,
            'supply': 0,
        },
        'RoachWarren': {
            'obj_id': [119],
            'priority': 6,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 0,
            'supply': 0,
        },
        'BanelingNest': {
            'obj_id': [118],
            'priority': 8,
            'type': ['building'],
            'mineral_cost': 100,
            'gas_cost': 50,
            'supply': 0,
        },
        'Lair': {
            'obj_id': [122],
            'priority': 30,
            'type': ['building', 'supply'],
            'mineral_cost': 150,
            'gas_cost': 100,
            'supply': 0,
        },
        'HydraliskDen': {
            'obj_id': [113],
            'priority': 18,
            'type': ['building'],
            'mineral_cost': 100,
            'gas_cost': 100,
            'supply': 0,
        },
        'LurkerDenMP': {
            'obj_id': [174],
            'priority': 16,
            'type': ['building'],
            'mineral_cost': 100,
            'gas_cost': 150,
            'supply': 0,
        },
        'Spire': {
            'obj_id': [114],
            'priority': 24,
            'type': ['building'],
            'mineral_cost': 200,
            'gas_cost': 200,
            'supply': 0,
        },
        'GreaterSpire': {
            'obj_id': [124],
            'priority': 22,
            'type': ['building'],
            'mineral_cost': 100,
            'gas_cost': 150,
            'supply': 0,
        },
        'NydusNetwork': {
            'obj_id': [117],
            'priority': 10,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 150,
            'supply': 0,
        },
        'NydusCanal': {
            'obj_id': [164],
            'priority': 10,
            'type': ['building'],
            'mineral_cost': 0,
            'gas_cost': 0,
            'supply': 0,
        },
        'NydusWorm': {
            'obj_id': [164],
            'priority': 10,
            'type': ['building'],
            'mineral_cost': 50,
            'gas_cost': 50,
            'supply': 0,
        },
        'InfestationPit': {
            'obj_id': [116],
            'priority': 12,
            'type': ['building'],
            'mineral_cost': 100,
            'gas_cost': 100,
            'supply': 0,
        },
        'Hive': {
            'obj_id': [123],
            'priority': 28,
            'type': ['building', 'supply'],
            'mineral_cost': 200,
            'gas_cost': 150,
            'supply': 0,
        },
        'UltraliskCavern': {
            'obj_id': [115],
            'priority': 14,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 200,
            'supply': 0,
        },
        'CreepTumor': {
            'obj_id': [159],
            'priority': 2,
            'type': ['building'],
            'mineral_cost': 0,
            'gas_cost': 0,
            'supply': 0,
        },
        'CreepTumorBurrowed': {
            'obj_id': [159],
            'priority': 2,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 200,
            'supply': 0,
        },
        'CreepTumorQueen': {
            'obj_id': [159],
            'priority': 2,
            'type': ['building'],
            'mineral_cost': 150,
            'gas_cost': 200,
            'supply': 0,
        },
    }
}
